----------------------------------------------------------------------------
-- xplordb
-- 
-- Copyright (C) 2022  Oslandia / OpenLog
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Affero General Public License as published
-- by the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Affero General Public License for more details.
-- 
-- You should have received a copy of the GNU Affero General Public License
-- along with this program.  If not, see <https://www.gnu.org/licenses/>.
-- 
-- __authors__ = ["davidms"]
-- __contact__ = "geology@oslandia.com"
-- __date__ = "2022/02/02"
-- __license__ = "AGPLv3"
----------------------------------------------------------------------------

--
-- PostgreSQL database dump
--
-- Dumped from database version 13.5 (Ubuntu 13.5-0ubuntu0.21.10.1)
-- Dumped by pg_dump version 13.5 (Ubuntu 13.5-0ubuntu0.21.10.1)
SET statement_timeout = 0;

SET lock_timeout = 0;

SET idle_in_transaction_session_timeout = 0;

SET client_encoding = 'UTF8';

SET standard_conforming_strings = ON;

SELECT
    pg_catalog.set_config('search_path', '', FALSE);

SET check_function_bodies = FALSE;

SET xmloption = content;

SET client_min_messages = warning;

SET row_security = OFF;

SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: raw; Type: TABLE; Schema: assay; Owner: postgres
--
CREATE TABLE assay.raw (
    line integer NOT NULL,
    batch text NOT NULL,
    sample_id text NOT NULL,
    "values" text
);

ALTER TABLE assay.raw OWNER TO postgres;

--
-- Name: TABLE raw; Type: COMMENT; Schema: assay; Owner: postgres
--
COMMENT ON TABLE assay.raw IS 'Imported raw lab file table';

--
-- Name: raw assay_raw_pkey; Type: CONSTRAINT; Schema: assay; Owner: postgres
--
ALTER TABLE ONLY assay.raw
    ADD CONSTRAINT assay_raw_pkey PRIMARY KEY (batch, sample_id, line);

--
-- PostgreSQL database dump complete
--
