----------------------------------------------------------------------------
-- xplordb
-- 
-- Copyright (C) 2022  Oslandia / OpenLog
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Affero General Public License as published
-- by the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Affero General Public License for more details.
-- 
-- You should have received a copy of the GNU Affero General Public License
-- along with this program.  If not, see <https://www.gnu.org/licenses/>.
-- 
-- __authors__ = ["davidms"]
-- __contact__ = "geology@oslandia.com"
-- __date__ = "2022/02/02"
-- __license__ = "AGPLv3"
----------------------------------------------------------------------------

--
-- PostgreSQL database dump
--

-- Dumped from database version 13.5 (Ubuntu 13.5-0ubuntu0.21.10.1)
-- Dumped by pg_dump version 13.5 (Ubuntu 13.5-0ubuntu0.21.10.1)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Data for Name: flat_method; Type: TABLE DATA; Schema: assay; Owner: postgres
--

COPY assay.flat_method (sample_id, "Ag", "Al", "As", "Au", "Au Check", "Au-Rpt1", "Au-Rpt2", "Au-Rpt3", "Au-Rpt4", "Au1", "Au2", "Au3", "B", "Ba", "Be", "Bi", "Br", "Ca", "Cd", "Ce", "Co", "Cr", "Cs", "Cu", "Digest_Run", "Digest_Seq", "Dy", "Er", "Eu", "Fe", "Final pH", "Fusion_Run", "Fusion_Seq", "Ga", "Gd", "Ge", "Hf", "Hg", "Ho", "I", "In", "Instr_Run", "Instr_Seq", "K", "LOI 1000", "La", "Li", "Lu", "Mg", "Mn", "Mo", "Na", "Nb", "Nd", "Ni", "P", "Pass2mm", "Pass6mm", "Pass75um", "Pb", "Pb 206", "Pb 207", "Pb 208", "Pd", "Pr", "Pt", "ROAST", "Rb", "Re", "Recvd
  Wt.", "Rmnd2mm", "Rmnd6mm", "Rmnd75um", "S", "Sb", "Sc", "Se", "Sm", "Sn", "Sr", "Ta", "Tb", "Te", "Th", "Ti", "Tl", "Tm", "U", "V", "W", "WO3", "WT. + Frac Entire", "WT. - Frac Entire", "WT. SAMPLE", "WT. Total", "Y", "Yb", "Zn", "Zr", p75um, u) FROM stdin;
6063583	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063290	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063690	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6074960	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578273	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595525	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063227	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3291	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	Cu-OG62	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
5255283	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3271	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074947	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074927	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255285	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063278	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652831	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074925	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074980	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578296	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3311	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3327	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578202	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063689	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063684	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
5255296	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578281	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578235	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578219	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255289	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063696	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3304	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3269	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3652820	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063699	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3578291	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3316	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578272	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063692	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
5255281	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3293	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074983	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074943	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578206	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3325	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063280	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652837	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074985	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595516	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578259	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074941	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578299	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3272	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578265	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578290	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578208	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578256	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063291	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578204	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3298	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	PUL-QC	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	PUL-QC	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	PUL-QC	\N	ME-ICP61	PUL-QC	\N	\N	ME-ICP61	\N	\N	\N
3578211	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255298	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3279	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063277	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578203	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063586	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578280	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578205	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652818	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3308	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063589	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074951	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255291	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3290	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	Cu-OG62	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6075692	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578271	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652841	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3285	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3283	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	Cu-OG62	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578229	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578268	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255260	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3313	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	Pb-OG62	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063286	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063691	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3652816	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074929	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578239	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578263	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074974	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652814	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063701	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3578228	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063285	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074970	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074946	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3323	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578047	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063279	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074933	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3306	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3318	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	PUL-QC	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	PUL-QC	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	PUL-QC	\N	ME-ICP61	PUL-QC	\N	\N	ME-ICP61	\N	\N	\N
6063705	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063284	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063702	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3578045	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074932	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075699	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063283	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3295	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3302	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074971	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3289	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3278	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	PUL-QC	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	PUL-QC	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	PUL-QC	\N	ME-ICP61	PUL-QC	\N	\N	ME-ICP61	\N	\N	\N
6074959	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255257	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3282	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6075695	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255258	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3277	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578267	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578285	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578279	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578043	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578253	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075697	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578286	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074923	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074948	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578048	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578212	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578248	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578234	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578293	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595521	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578049	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063703	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6075698	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063222	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6075693	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578220	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074928	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074934	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578292	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578251	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578283	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075686	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074958	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595526	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578216	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578288	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063694	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
5255256	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
5255288	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3299	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3652822	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074935	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578277	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074982	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3305	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
5255261	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652823	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578224	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578266	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578294	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578284	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3324	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074945	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255255	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652835	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074938	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063695	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063282	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578217	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595524	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652819	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3273	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3652839	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578209	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578215	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063682	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063704	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6074957	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063221	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578233	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063697	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6074963	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074944	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255284	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578210	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595517	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074975	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075690	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652834	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075691	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255290	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063587	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074949	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255297	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6075688	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578287	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063678	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3578289	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578042	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
5255287	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578260	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063223	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578237	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578245	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578298	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3315	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
5255293	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578044	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074967	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063584	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074955	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578241	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074936	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063287	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
5255292	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063679	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3578231	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255286	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578218	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074965	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652828	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578242	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652836	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578236	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063281	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578046	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074966	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3276	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074939	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074979	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074964	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578230	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578243	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652829	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255259	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063681	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3292	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	Cu-OG62	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578262	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3326	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063685	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3322	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074931	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595522	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578052	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652813	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074952	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3274	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6075689	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578269	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3328	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578223	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595520	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652838	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595515	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063588	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578264	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3284	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
5255294	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3294	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074922	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3319	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578244	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074930	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578252	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063688	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3296	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578201	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075696	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063680	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3652815	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652812	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578258	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063289	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578297	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652827	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3275	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063698	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
3578214	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074937	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063220	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3595518	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578227	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3309	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578278	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3297	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074921	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578222	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3595523	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063224	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578246	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063683	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6074956	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075694	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578295	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578282	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255254	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578232	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074954	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3270	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074969	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6075700	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652832	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3310	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578249	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074978	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3281	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578221	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652840	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063686	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063582	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578247	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074942	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578261	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652811	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3312	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
5255253	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578207	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652833	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074968	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074953	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3286	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3652810	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074962	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063581	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3652824	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3303	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074961	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074940	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063585	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3320	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063687	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063288	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6063693	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	WEI-21	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N
6063591	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578270	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578257	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3307	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3300	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6074973	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063219	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3595519	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3280	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3301	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6063228	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
5255282	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
6074977	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063590	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578226	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074984	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578238	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3321	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3652817	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074981	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074924	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
5255295	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3317	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578213	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6074972	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3314	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
6075687	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3287	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3288	ME-ICP61	ME-ICP61	ME-ICP61	Au-AA25	\N	\N	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	\N	Cu-OG62	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	Au-AA25	Au-AA25	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	ME-ICP61	ME-ICP61	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N	ME-ICP61	\N	\N	\N
3578051	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578255	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3578274	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
6063580	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
3578240	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652821	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
3652808	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	ICPOES	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICPOES	\N	\N	\N	\N	ICPOES	ICPOES	ICPOES	ICPOES	ICPOES	\N	ICPOES	ICPOES	\N	\N	\N	ICPOES	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEI-21	\N	\N	\N	ICPOES	ICPOES	\N	\N	\N	\N	ICPOES	\N	\N	\N	ICPOES	ICPOES	\N	\N	ICPOES	ICPOES	ICPOES	\N	\N	\N	\N	\N	\N	\N	ICPOES	ICPOES	\N	\N
\.


--
-- PostgreSQL database dump complete
--

